<head>
  <meta charset="utf-8" />
  <style type="text/css">
    body {
    	font-family: "Microsoft YaHei";
    	font-weight: bold;
    	font-size: 20px;
    	line-height: 35px;
    }

    .text {
    	margin-top: 5px;
    	word-break: break-all;
    	white-space: pre-wrap;

    }

    .main-box {
    	padding: 5px;
    }
  </style>
</head>
<body>
  <div id="main" class="main-box">
    <div class="text">{{ data['text'] }}</div>
  </div>
</body>
