# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hikari_core',
 'hikari_core.Html_Render',
 'hikari_core.game',
 'hikari_core.moudle']

package_data = \
{'': ['*'],
 'hikari_core': ['Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html'],
 'hikari_core.Html_Render': ['templates/*']}

install_requires = \
['APScheduler>=3.10.1,<4.0.0',
 'aiofiles>=0.8.0',
 'asyncio>=3.4.3,<4.0.0',
 'beautifulsoup4>=4.12.2,<5.0.0',
 'httpx[http2]>=0.24.0',
 'jinja2>=3.0.0,<4.0.0',
 'json_tools>=0.4.1,<0.5.0',
 'loguru>=0.7.0,<0.8.0',
 'orjson>=3.8.11,<4.0.0',
 'playwright>=1.17.2',
 'pydantic>=1.10.7,<2.0.0']

setup_kwargs = {
    'name': 'hikari-core',
    'version': '1.0.6.2',
    'description': 'SDK for yuyuko,战舰世界yuyuko平台BOT SDK',
    'long_description': '# Hikari-core\nSDK for yuyuko API\n',
    'author': 'benx1n',
    'author_email': '1119809439@qq.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/wows-yuyuko/Hikari-core',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
